pub struct NodeQueue { /* private fields */ }Implementations
Sourceimpl NodeQueue
The node queue can be used to iterate nodes in order. It has a number of specific requirements:
impl NodeQueue
The node queue can be used to iterate nodes in order. It has a number of specific requirements:
- It assumes all nodes are consecutive integers starting from 0
- It assumes all nodes are present in the queue at the time of initialization.
- No new nodes will show up during processing, i.e. all indexes 0..n must be known at initialization.